#include "SamplingPreprocessor.h"
#include "ExactPreprocessor.h"
#include "Parser.h"
#include "UnigraphicsParser.h"
#include "X3dParser.h"
#include "Environment.h"
#include "Camera.h"
#include "MeshKdTree.h"

#define USE_EXE_PATH false


int
main(int argc, const char **argv)
{
  Debug.open("debug.log");
  environment = new Environment;
  environment->Parse(argc, argv, USE_EXE_PATH);
  MeshKdTree::ParseEnvironment();
  
  Preprocessor *p =
    new SamplingPreprocessor();

  char buff[128];
  environment->GetStringValue("Scene.filename", buff);
  string filename(buff);

  p->LoadScene(filename);
  p->BuildKdTree();
  p->KdTreeStatistics(cout);

#ifdef DEST_BSP_VIEWCELLS
  p->GenerateViewcells();
  p->BspTreeStatistics(cout);
#endif

  //  p->mSceneGraph->Export("soda.x3d");
  if (0) {
    p->Export(filename + "-out.x3d", true, false);
    p->Export(filename + "-kdtree.x3d", false, true);
  }
  
  //  p->LoadViewcells("viewcells.wrl");
  if (1) {
    p->ComputeVisibility();
    p->ExportPreprocessedData("scene.vis");
  }
  
  if (0) {
    Camera camera;
    camera.LookAtBox(p->mKdTree->GetBox());
    camera.SnapImage("camera.jpg", p->mKdTree);

    
    camera.LookInBox(p->mKdTree->GetBox());
    camera.SetPosition(camera.mPosition - Vector3(0,100,0));
    camera.SnapImage("camera2.png", p->mKdTree);
  }

  
  return 0;
}

